@@ -216,6 +216,9 @@ class Formatoption(object):
     #: included in the gui. If None, the key is used in the gui
     name = None
 
+    #: Boolean that is True if an update of the formatoption requires a replot
+    requires_replot = False
+
     @property
     def init_kwargs(self):
         """:class:`dict` key word arguments that are passed to the
@@ -316,16 +319,18 @@ class Formatoption(object):
     @property
     def iter_data(self):
         """Returns an iterator over the plot data arrays"""
-        if isinstance(self.data, InteractiveList):
-            return iter(self.data)
-        return iter([self.data])
+        data = self.data
+        if isinstance(data, InteractiveList):
+            return iter(data)
+        return iter([data])
 
     @property
     def iter_raw_data(self):
         """Returns an iterator over the original data arrays"""
-        if isinstance(self.raw_data, InteractiveList):
-            return iter(self.raw_data)
-        return iter([self.raw_data])
+        data = self.raw_data
+        if isinstance(data, InteractiveList):
+            return iter(data)
+        return iter([data])
 
     @property
     def validate(self):
@@ -398,7 +403,9 @@ class Formatoption(object):
 
     @docstrings.get_sectionsf('Formatoption')
     @dedent
-    def __init__(self, key, plotter=None, index_in_list=None, **kwargs):
+    def __init__(self, key, plotter=None, index_in_list=None,
+                 additional_children=[], additional_dependencies=[],
+                 **kwargs):
         """
         Parameters
         ----------
@@ -410,6 +417,11 @@ class Formatoption(object):
         index_in_list: int or None
             The index that shall be used if the data is a
             :class:`psyplot.InteractiveList`
+        additional_children: list or str
+            Additional children to use (see the :attr:`children` attribute)
+        additional_dependencies: list or str
+            Additional dependencies to use (see the :attr:`dependencies`
+            attribute)
         ``**kwargs``
             Further keywords may be used to specify different names for
             children, dependencies and connection formatoptions that match the
@@ -421,6 +433,10 @@ class Formatoption(object):
         self.plotter = plotter
         self.index_in_list = index_in_list
         self.shared = set()
+        self.additional_children = additional_children
+        self.additional_dependencies = additional_dependencies
+        self.children = self.children + additional_children
+        self.dependencies = self.dependencies + additional_dependencies
         self._child_mapping = dict(zip(*tee(chain(
             self.children, self.dependencies, self.connections,
             self.parents), 2)))
@@ -450,7 +466,10 @@ class Formatoption(object):
             return getattr(instance, '_' + self.key)
         except AttributeError:
             fmto = self.__class__(
-                self.key, instance, self.index_in_list, **self.init_kwargs)
+                self.key, instance, self.index_in_list,
+                additional_children=self.additional_children,
+                additional_dependencies=self.additional_dependencies,
+                **self.init_kwargs)
             setattr(instance, '_' + self.key, fmto)
             return fmto
 
@@ -604,6 +623,28 @@ class Formatoption(object):
             Value to update"""
         pass
 
+    def get_fmt_widget(self, parent, project):
+        """Get a widget to update the formatoption in the GUI
+
+        This method should return a QWidget that is loaded by the psyplot-gui
+        when the formatoption is selected in the
+        :attr:`psyplot_gui.main.Mainwindow.fmt_widget`. It should call the
+        :method:`~psyplot_gui.fmt_widget.FormatoptionWidget.insert_text` method
+        when the update text for the formatoption should be changed.
+
+        Parameters
+        ----------
+        parent: psyplot_gui.fmt_widget.FormatoptionWidget
+            The parent widget that contains the returned QWidget
+        project: psyplot.project.Project
+            The current subproject (see :func:`psyplot.project.gcp`)
+
+        Returns
+        -------
+        PyQt5.QtWidgets.QWidget
+            The widget to control the formatoption"""
+        return None
+
     def share(self, fmto, initializing=False, **kwargs):
         """Share the settings of this formatoption with other data objects
 
@@ -745,6 +786,15 @@ class PostTiming(Formatoption):
     def update(self, value):
         pass
 
+    def get_fmt_widget(self, parent, project):
+        from psyplot_gui.compat.qtcompat import QComboBox
+        combo = QComboBox(parent)
+        combo.addItems(['never', 'always', 'replot'])
+        combo.setCurrentText(
+            next((plotter[self.key] for plotter in project.plotters), 'never'))
+        combo.currentTextChanged.connect(parent.set_obj)
+        return combo
+
 
 class PostProcDependencies(object):
     """The dependencies of this formatoption"""
@@ -854,7 +904,6 @@ class PostProcessing(Formatoption):
             exec(value, {'self': self})
 
 
-@docstrings.get_sectionsf('Plotter')
 class Plotter(dict):
     """Interactive plotting object for one or more data arrays
 
@@ -1262,6 +1311,7 @@ class Plotter(dict):
         if clear:
             self.logger.debug("    Clearing axes...")
             self.ax.clear()
+            self.cleared = True
         # get the formatoptions. We sort them here by key to make sure that the
         # order always stays the same (easier for debugging)
         fmto_groups = self._grouped_fmtos(self._sorted_by_priority(
@@ -1369,7 +1419,7 @@ class Plotter(dict):
             # get the formatoptions. We sort them here by key to make sure that
             # the order always stays the same (easier for debugging)
             fmtos = sorted(self._set_and_filter(), key=lambda fmto: fmto.key)
-        except:
+        except Exception:
             # restore last (working) state
             last_state = self._old_fmt.pop(-1)
             with self.no_validation:
@@ -1403,10 +1453,17 @@ class Plotter(dict):
             return True
         # otherwise we update it
         arr_draw = False
-        for priority, grouper in fmto_groups:
-            arr_draw = True
-            self._plot_by_priority(priority, grouper)
-        update_the_others()
+        try:
+            for priority, grouper in fmto_groups:
+                arr_draw = True
+                self._plot_by_priority(priority, grouper)
+            update_the_others()
+        except Exception:
+            raise
+        finally:
+            # make sure that all locks are released
+            self._release_all(finish=True,
+                              queue=None if queues is None else queues[1])
         if draw is None:
             draw = rcParams['auto_draw']
         if draw and arr_draw:
@@ -1414,8 +1471,6 @@ class Plotter(dict):
             if rcParams['auto_show']:
                 self.show()
         self.replot = False
-        # make sure that all locks are released
-        self._release_all(True, queue=None if queues is None else queues[1])
         return arr_draw
 
     def _release_all(self, finish=False, queue=None):
@@ -1602,9 +1657,11 @@ class Plotter(dict):
                 fmto.dependencies)))
         seen = seen or {fmto.key for fmto in fmtos}
         keys = {fmto.key for fmto in fmtos}
+        self.replot = self.replot or any(
+            fmto.requires_replot for fmto in fmtos)
         if self.replot or any(fmto.priority >= START for fmto in fmtos):
             self.replot = True
-            self.plot_data = self.data.copy(True)
+            self.plot_data = self.data
             new_fmtos = dict((f.key, f) for f in self._fmtos
                              if ((f not in fmtos and is_data_dependent(
                                  f, self.data))))
